BIND_METHODS = {"bind", "bind_all", "bind_class", "tag_bind"}
BIND_METHODS.add("bind_with_data")  # For Porcupine

COMMAND_ARGS = {"command", "xscrollcommand", "yscrollcommand", "postcommand"}
CONFIG_METHODS = {"config", "configure"}

DUMB_CONSTANTS = {"TRUE", "FALSE", "YES", "NO", "ON", "OFF"}

GM_METHODS = {"place", "pack", "grid"}
